==> nmrium-0.50.1.tgz: package/lib/component/toolbar/toolbarMenu.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { FaCopy, FaDownload, FaFile, FaFileDownload, FaFileImage, } from 'react-icons/fa';
const IMPORT_MENU = [
    {
        icon: _jsx(FaFile, {}),
        text: 'Import from file system (Press Ctrl + O)',
        data: {
            id: 'importFile',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Add JCAMP-DX from URL',
        data: {
            id: 'importJDX',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Generate spectrum from publication string',
        data: {
            id: 'importPublicationString',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Import meta information',
        data: {
            id: 'importMetaInformation',
        },
    },
];
const EXPORT_MENU = [
    {
        icon: _jsx(FaDownload, {}),
        text: 'Export as SVG',
        data: {
            id: 'svg',
        },
    },
    {
        icon: _jsx(FaFileImage, {}),
        text: 'Export as PNG',
        data: {
            id: 'png',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save data ( Press Ctrl + S )',
        data: {
            id: 'json',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save data as  ( Press Ctrl + Shift + S )',
        data: {
            id: 'advance_save',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save NMRE data',
        data: {
            id: 'nmre',
        },
    },
    {
        icon: _jsx(FaCopy, {}),
        text: 'Copy image to Clipboard ( Press Ctrl + C )',
        data: {
            id: 'copy',
        },
    },
];
export { EXPORT_MENU, IMPORT_MENU };

==> nmrium-0.53.0.tgz: package/lib/component/toolbar/toolbarMenu.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { FaCopy, FaDownload, FaFile, FaFileDownload, FaFileImage, } from 'react-icons/fa';
const IMPORT_MENU = [
    {
        icon: _jsx(FaFile, {}),
        text: 'Import from file system (Press Ctrl+o)',
        data: {
            id: 'importFile',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Add JCAMP-DX from URL',
        data: {
            id: 'importJDX',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Generate spectrum from publication string',
        data: {
            id: 'importPublicationString',
        },
    },
    {
        icon: _jsx(FaFile, {}),
        text: 'Import meta information',
        data: {
            id: 'importMetaInformation',
        },
    },
];
const EXPORT_MENU = [
    {
        icon: _jsx(FaDownload, {}),
        text: 'Export as SVG',
        data: {
            id: 'svg',
        },
    },
    {
        icon: _jsx(FaFileImage, {}),
        text: 'Export as PNG',
        data: {
            id: 'png',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save data (Press Ctrl+s)',
        data: {
            id: 'json',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save data as (Press Ctrl+Shift+s)',
        data: {
            id: 'advance_save',
        },
    },
    {
        icon: _jsx(FaFileDownload, {}),
        text: 'Save NMRE data',
        data: {
            id: 'nmre',
        },
    },
    {
        icon: _jsx(FaCopy, {}),
        text: 'Copy image to clipboard (Press Ctrl+c)',
        data: {
            id: 'copy',
        },
    },
];
export { EXPORT_MENU, IMPORT_MENU };
